@@ -1,15 +1,16 @@
 from django.conf import settings
+from django.utils.six.moves import http_client
 
 from csp.utils import build_policy
 
 
 class CSPMiddleware(object):
     """
-    Implements the X-Content-Security-Policy response header, which
+    Implements the Content-Security-Policy response header, which
     conforming user-agents can use to restrict the permitted sources
     of various content.
 
-    See https://wiki.mozilla.org/Security/CSP/Specification
+    See http://www.w3.org/TR/CSP/
 
     """
 
@@ -22,6 +23,11 @@ class CSPMiddleware(object):
         if request.path_info.startswith(prefixes):
             return response
 
+        # Check for debug view
+        status_code = response.status_code
+        if status_code == http_client.INTERNAL_SERVER_ERROR and settings.DEBUG:
+            return response
+
         header = 'Content-Security-Policy'
         if getattr(settings, 'CSP_REPORT_ONLY', False):
             header += '-Report-Only'
